@@ -8,6 +8,6 @@
 #' @examples
 #' ritu(2)
 ritu <- function(masa_num){
-  return (((masa_num - 1) %/% 2) + 1)
+  return (((masa_num[1] - 1) %/% 2) + 1)
 }
-# ---------------------------------------------------------------------------- #
\ No newline at end of file
+# ---------------------------------------------------------------------------- #
